# PyKrev: van Krevelen analysis and beyond

PyKrev is a Python 3 library to help with analysis of high resolution mass spectrometry data.

To install use:

```
pip install pykrev
```

[**The User Guide can be accessed here**](https://github.com/Kzra/PyKrev/blob/master/docs/PyKrevUserGuide.md)

[*Making UpSet plots with PyKrev and UpSetPlot*](https://github.com/Kzra/PyKrev/blob/master/docs/UpSetplotswithPyKrev.md)

[*Performing PCA with PyKrev and scikit-learn*](https://github.com/Kzra/PyKrev/blob/master/docs/PCAwithPyKrev.md)

Version 1.0.0 [*Changelog*](https://github.com/Kzra/pykrev/blob/master/CHANGELOG.md)

Please send any feedback or comments to ezra.kitson@ed.ac.uk

<img src="https://github.com/Kzra/pykrev/blob/master/docs/Pykrev_blue.png" alt="PyKrev" width="650"/>
